import os
import sys
import subprocess
from re import search, match, sub
from time import sleep, time, monotonic
from timeit import timeit
from datetime import datetime, timedelta, timezone # tz=timezone.utc
from functools import partial, reduce, cache
from itertools import tee, count, cycle, repeat, chain, pairwise
from statistics import mean, median, stdev
from pprint import pp
from tabulate import tabulate
from random import randint, shuffle
import threading as thrd
import multiprocessing as mp
from glob import glob
from collections import deque, defaultdict, namedtuple
import json
import pickle


from setuptools import setup, find_packages

VERSION = '1.3.3.7.2'
DESCRIPTION = 'Rotary Saw'
LONG_DESCRIPTION = 'Turrican turns into a rotary saw in combat. This is my personal import collection for quick scripts and helpers. So Nice to have it under PyPi. It will not be useful for whomever finds this, but I hope it could be one day.'

# Setting up
setup(
    # the name must match the folder name 'verysimplemodule'
    name="rotarysaw",
    version=VERSION,
    author="Kuu Tirronen",
    author_email="<kuu@uraanikaivos.fi>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['tabulate'],  # add any additional packages that
    # needs to be installed along with your package. Eg: 'caer'

    keywords=['python', 'turrican', 'rotary saw', 'tirronen', 'rotarysaw'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.11',
    ]
)


# QtCore
from PyQt6.QtCore import pyqtSignal, pyqtSlot
from PyQt6.QtCore import QStringListModel, QConcatenateTablesProxyModel, QAbstractProxyModel, QPersistentModelIndex, QIdentityProxyModel
from PyQt6.QtCore import QModelIndex, QAbstractTableModel, QTransposeProxyModel, QAbstractListModel, QItemSelectionModel
from PyQt6.QtCore import QAbstractItemModel, QSortFilterProxyModel, QModelRoleData, QXmlStreamNamespaceDeclaration, QCborStreamReader
from PyQt6.QtCore import QXmlStreamEntityDeclaration, QXmlStreamAttributes, QDataStream, QXmlStreamAttribute, QXmlStreamWriter
from PyQt6.QtCore import QXmlStreamReader, QCborStreamWriter, QTextStream, QXmlStreamEntityResolver, QTextStreamManipulator
from PyQt6.QtCore import QXmlStreamNotationDeclaration, QEventLoopLocker, QChildEvent, QAbstractEventDispatcher, QDynamicPropertyChangeEvent
from PyQt6.QtCore import QEventLoop, QTimerEvent, QEvent, QAbstractNativeEventFilter
from PyQt6.QtCore import QFile, QLockFile, QSaveFile, QFileSelector, QTemporaryFile
from PyQt6.QtCore import QFileSystemWatcher, QFileInfo, QFileDevice, QAbstractAnimation, QVariantAnimation
from PyQt6.QtCore import QPauseAnimation, QAnimationGroup, QPropertyAnimation, QParallelAnimationGroup, QSequentialAnimationGroup
from PyQt6.QtCore import QMetaProperty, QMetaObject, QMetaType, QMetaClassInfo, QMetaEnum
from PyQt6.QtCore import QMetaMethod, QDeadlineTimer, QTimer, QBasicTimer, QElapsedTimer
from PyQt6.QtCore import QCborSimpleType, QCborKnownTags, QCborError, QMimeType, QtMsgType
from PyQt6.QtCore import QTypeRevision, QLineF, QCommandLineParser, QCommandLineOption, QLine
from PyQt6.QtCore import QTimeLine, QStorageInfo, QSysInfo, QLibraryInfo, QSizeF
from PyQt6.QtCore import QPointF, QMarginsF, QRectF, QStringDecoder, QStringConverterBase
from PyQt6.QtCore import QStringEncoder, QStringConverter, QItemSelectionRange, QItemSelection, QDateTime
from PyQt6.QtCore import QTime, QTimeZone, QWriteLocker, QMutexLocker, QReadLocker
from PyQt6.QtCore import QOperatingSystemVersion, QSystemSemaphore, QOperatingSystemVersionBase, QByteArrayMatcher, QBitArray
from PyQt6.QtCore import QByteArray, QMimeData, QTemporaryDir, QDirIterator, QDir
from PyQt6.QtCore import QIODeviceBase, QIODevice, QJsonDocument, QJsonValue, QJsonParseError
from PyQt6.QtCore import QMessageAuthenticationCode, QMessageLogContext, QMessageLogger, QObject, QObjectCleanupHandler
from PyQt6.QtCore import QMimeDatabase, QMutex, QRecursiveMutex, QVersionNumber, QRegularExpressionMatch
from PyQt6.QtCore import QRegularExpressionMatchIterator, QRegularExpression, QSemaphoreReleaser, QSemaphore, QTextBoundaryFinder
from PyQt6.QtCore import QCollatorSortKey, QCollator, QKeyCombination, QDate, QGenericReturnArgument
from PyQt6.QtCore import QGenericArgument, QLibrary, QReadWriteLock, QMargins, QPoint
from PyQt6.QtCore import QProcessEnvironment, QProcess, QRect, QSignalMapper, QSignalBlocker
from PyQt6.QtCore import QSize, QSocketNotifier, QThread, QThreadPool, QUrl
from PyQt6.QtCore import QUrlQuery, QVariant, Qt, QBuffer, QCalendar
from PyQt6.QtCore import QCoreApplication, QCryptographicHash, QEasingCurve, QLocale, QLoggingCategory
from PyQt6.QtCore import QPluginLoader, QRandomGenerator, QResource, QRunnable, QSettings
from PyQt6.QtCore import QSharedMemory, QStandardPaths, QTranslator, QUuid, QWaitCondition
# QtGui
from PyQt6.QtGui import QTouchEvent, QDragEnterEvent, QDropEvent, QResizeEvent, QNativeGestureEvent
from PyQt6.QtGui import QHelpEvent, QInputMethodQueryEvent, QEnterEvent, QScrollEvent, QActionEvent
from PyQt6.QtGui import QFileOpenEvent, QShowEvent, QCloseEvent, QSinglePointEvent, QContextMenuEvent
from PyQt6.QtGui import QTabletEvent, QPlatformSurfaceEvent, QStatusTipEvent, QInputEvent, QKeyEvent
from PyQt6.QtGui import QMoveEvent, QIconDragEvent, QInputMethodEvent, QHoverEvent, QDragLeaveEvent
from PyQt6.QtGui import QWheelEvent, QWhatsThisClickedEvent, QDragMoveEvent, QShortcutEvent, QHideEvent
from PyQt6.QtGui import QScrollPrepareEvent, QExposeEvent, QEventPoint, QWindowStateChangeEvent, QMouseEvent
from PyQt6.QtGui import QPaintEvent, QFocusEvent, QPointerEvent, QTextBlock, QAbstractTextDocumentLayout
from PyQt6.QtGui import QTextCursor, QTextFrameFormat, QTextTableCellFormat, QTextObjectInterface, QTextImageFormat
from PyQt6.QtGui import QTextLine, QTextTableCell, QTextCharFormat, QTextFrame, QTextBlockUserData
from PyQt6.QtGui import QTextList, QTextFormat, QTextDocumentFragment, QTextTable, QStaticText
from PyQt6.QtGui import QTextInlineObject, QTextLayout, QTextListFormat, QTextLength, QTextDocumentWriter
from PyQt6.QtGui import QTextTableFormat, QTextBlockFormat, QTextItem, QTextFragment, QTextDocument
from PyQt6.QtGui import QTextObject, QTextOption, QTextBlockGroup, QSurfaceFormat, QPixelFormat
from PyQt6.QtGui import QMatrix2x2, QMatrix3x4, QMatrix4x2, QMatrix3x2, QMatrix2x4
from PyQt6.QtGui import QMatrix4x3, QMatrix4x4, QMatrix2x3, QMatrix3x3, QFont
from PyQt6.QtGui import QFontDatabase, QRawFont, QFontMetrics, QFontMetricsF, QFontInfo
from PyQt6.QtGui import QInputDevice, QPointingDeviceUniqueId, QPointingDevice, QPaintDeviceWindow, QPagedPaintDevice
from PyQt6.QtGui import QPaintDevice, QPaintEngineState, QPaintEngine, QDrag, QImageIOHandler
from PyQt6.QtGui import QImage, QImageReader, QImageWriter, QInputMethod, QAbstractFileIconProvider
from PyQt6.QtGui import QIcon, QIconEngine, QOpenGLContextGroup, QUndoGroup, QActionGroup
from PyQt6.QtGui import QColorSpace, QColorConstants, QColorTransform, QColor, QGradient
from PyQt6.QtGui import QLinearGradient, QRadialGradient, QConicalGradient, QIntValidator, QValidator
from PyQt6.QtGui import QDoubleValidator, QRegularExpressionValidator, QSurface, QOffscreenSurface, QWindow
from PyQt6.QtGui import QRasterWindow, QFileSystemModel, QPageLayout, QAction, QOpenGLContext
from PyQt6.QtGui import QPdfWriter, QPageRanges, QPageSize, QPainterPath, QPainterPathStroker
from PyQt6.QtGui import QPainter, QStandardItemModel, QStandardItem, QUndoStack, QUndoCommand
from PyQt6.QtGui import QVector3D, QVector4D, QVector2D, QTransform, QCursor
from PyQt6.QtGui import QPolygonF, QKeySequence, QPixmap, QPixmapCache, QPolygon
from PyQt6.QtGui import QShortcut, QBackingStore, QBitmap, QBrush, QClipboard
from PyQt6.QtGui import QDesktopServices, QGlyphRun, QGuiApplication, QMovie, QPalette
from PyQt6.QtGui import QPen, QPicture, QQuaternion, QRegion, QRgba64
from PyQt6.QtGui import QScreen, QSessionManager, QStyleHints, QSyntaxHighlighter
# QtWidgets
from PyQt6.QtWidgets import QGraphicsRectItem, QAbstractGraphicsShapeItem, QGraphicsSceneHelpEvent, QGraphicsSceneHoverEvent, QGraphicsProxyWidget
from PyQt6.QtWidgets import QGraphicsSceneContextMenuEvent, QGraphicsSceneDragDropEvent, QGraphicsRotation, QGraphicsLineItem, QGraphicsBlurEffect
from PyQt6.QtWidgets import QGraphicsItemGroup, QGraphicsPolygonItem, QGraphicsScene, QGraphicsPixmapItem, QGraphicsTextItem
from PyQt6.QtWidgets import QStyleOptionGraphicsItem, QGraphicsLinearLayout, QGraphicsScale, QGraphicsOpacityEffect, QGraphicsDropShadowEffect
from PyQt6.QtWidgets import QGraphicsSceneMouseEvent, QGraphicsSceneEvent, QGraphicsTransform, QGraphicsSceneMoveEvent, QGraphicsPathItem
from PyQt6.QtWidgets import QGraphicsEllipseItem, QGraphicsAnchor, QGraphicsObject, QGraphicsLayoutItem, QGraphicsEffect
from PyQt6.QtWidgets import QGraphicsView, QGraphicsWidget, QGraphicsSceneWheelEvent, QGraphicsLayout, QGraphicsSceneResizeEvent
from PyQt6.QtWidgets import QGraphicsGridLayout, QGraphicsColorizeEffect, QGraphicsItem, QGraphicsSimpleTextItem, QGraphicsAnchorLayout
from PyQt6.QtWidgets import QStyleOptionViewItem, QStyleOptionSpinBox, QStylePainter, QStyleOptionGroupBox, QStyleOptionSlider
from PyQt6.QtWidgets import QStyleOptionTabBarBase, QStyleOptionButton, QCommonStyle, QStyleOptionSizeGrip, QStyleOptionHeaderV2
from PyQt6.QtWidgets import QStyleOptionDockWidget, QStyle, QStyleOptionHeader, QStyleOptionTabWidgetFrame, QStyleOptionToolBar
from PyQt6.QtWidgets import QStyleOptionToolBox, QStyleHintReturnVariant, QStyleOptionRubberBand, QStyleOptionToolButton, QStyleOptionFrame
from PyQt6.QtWidgets import QStyleHintReturn, QProxyStyle, QStyleOptionTab, QStyleOptionComboBox, QStyleOption
from PyQt6.QtWidgets import QStyleOptionFocusRect, QStyleOptionProgressBar, QStyleOptionMenuItem, QStyleFactory, QStyleHintReturnMask
from PyQt6.QtWidgets import QStyleOptionTitleBar, QStyleOptionComplex, QTreeWidgetItemIterator, QAbstractItemDelegate, QLayoutItem
from PyQt6.QtWidgets import QTreeWidgetItem, QStyledItemDelegate, QAbstractItemView, QListWidgetItem, QItemEditorFactory
from PyQt6.QtWidgets import QSpacerItem, QItemDelegate, QTableWidgetItem, QWidgetItem, QItemEditorCreatorBase
from PyQt6.QtWidgets import QWidget, QTreeWidget, QStackedWidget, QTabWidget, QTableWidgetSelectionRange
from PyQt6.QtWidgets import QTableWidget, QDockWidget, QWidgetAction, QDataWidgetMapper, QCalendarWidget
from PyQt6.QtWidgets import QListWidget, QCheckBox, QDoubleSpinBox, QFontComboBox, QGroupBox
from PyQt6.QtWidgets import QHBoxLayout, QDialogButtonBox, QAbstractSpinBox, QComboBox, QSpinBox
from PyQt6.QtWidgets import QBoxLayout, QMessageBox, QToolBox, QVBoxLayout, QStackedLayout
from PyQt6.QtWidgets import QGridLayout, QPlainTextDocumentLayout, QLayout, QFormLayout, QGestureEvent
from PyQt6.QtWidgets import QTabBar, QToolBar, QProgressBar, QMenuBar, QStatusBar
from PyQt6.QtWidgets import QScrollBar, QRadioButton, QCommandLinkButton, QAbstractButton, QButtonGroup
from PyQt6.QtWidgets import QPushButton, QToolButton, QListView, QHeaderView, QUndoView
from PyQt6.QtWidgets import QColumnView, QTableView, QTreeView, QTapAndHoldGesture, QPinchGesture
from PyQt6.QtWidgets import QSwipeGesture, QTapGesture, QPanGesture, QGesture, QGestureRecognizer
from PyQt6.QtWidgets import QAbstractSlider, QAbstractScrollArea, QProgressDialog, QInputDialog, QFileDialog
from PyQt6.QtWidgets import QColorDialog, QDialog, QFontDialog, QTimeEdit, QPlainTextEdit
from PyQt6.QtWidgets import QKeySequenceEdit, QDateTimeEdit, QDateEdit, QLineEdit, QTextEdit
from PyQt6.QtWidgets import QToolTip, QTextBrowser, QFocusFrame, QFrame, QMenu
from PyQt6.QtWidgets import QScrollArea, QMdiArea, QSlider, QSizePolicy, QSizeGrip
from PyQt6.QtWidgets import QErrorMessage, QFileIconProvider, QSystemTrayIcon, QMainWindow, QMdiSubWindow
from PyQt6.QtWidgets import QRubberBand, QScroller, QScrollerProperties, QSplitterHandle, QSplitter
from PyQt6.QtWidgets import QWizard, QWizardPage, QApplication, QCompleter, QDial
from PyQt6.QtWidgets import QLCDNumber, QLabel, QSplashScreen, QWhatsThis
